@@ -1,5 +1,7 @@
 use std::convert::TryFrom;
 
+use smartstring::alias::String;
+
 use crate::Error;
 use crate::Title;
 use crate::TitleType;
@@ -20,11 +22,11 @@ impl Movie {
 	pub(crate) fn new(imdb_id: u64, title: &str, is_adult: bool, year: u16, runtime_minutes: Option<u16>, genres: &[&str]) -> Self {
 		Self{
 			imdb_id,
-			title: title.to_string(),
+			title: String::from(title),
 			is_adult,
 			year,
 			runtime_minutes,
-			genres: genres.iter().map(|s| s.to_string()).collect()
+			genres: genres.iter().map(|s| String::from(*s)).collect()
 		}
 	}
 
@@ -52,7 +54,7 @@ impl TryFrom<&Title> for Movie {
 				runtime_minutes: input.runtime_minutes,
 				genres: input.genres.clone()
 			}),
-			_ => Err(Error::WrongMediaType(input.title_type.to_string(), "Movie".to_string()))
+			_ => Err(Error::WrongMediaType(input.title_type.into(), "Movie"))
 		}
 	}
 }
